%define		major		1.7
%define		libname		%mklibname openimageio %{major}
%define		develname	%mklibname openimageio -d

Name:		openimageio
Version:	1.7.14
Release:	%mkrel 1
Summary:	Library for reading and writing images
Group:		System/Libraries
License:	BSD
URL:		https://sites.google.com/site/openimageio/home
Source0:	https://github.com/OpenImageIO/oiio/archive/Release-%{version}.tar.gz
Patch0:		OpenImageIO-1.7.9-dl.patch
Patch1:		OpenImageIO-uninit.patch
BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	giflib-devel
BuildRequires:	hdf5-devel
BuildRequires:	ilmbase-devel
BuildRequires:	libjpeg-devel
BuildRequires:	OpenEXR-devel
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(jasper)
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
BuildRequires:	pkgconfig(libopenjpeg1)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libraw)
BuildRequires:	pkgconfig(libraw_r)
BuildRequires:	pkgconfig(libswscale)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libwebp)
BuildRequires:	pkgconfig(OpenColorIO)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(python2)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pugixml-devel
BuildRequires:	qt4-devel
BuildRequires:	txt2man

Obsoletes:	OpenImageIO < %{version}

%description
OpenImageIO is a library for reading and writing images, and a bunch of related
classes, utilities, and applications. Main features include:
- Extremely simple but powerful ImageInput and ImageOutput APIs for reading and
  writing 2D images that is format agnostic.
- Format plugins for TIFF, JPEG/JFIF, OpenEXR, PNG, HDR/RGBE, Targa, JPEG-2000,
  DPX, Cineon, FITS, BMP, ICO, RMan Zfile, Softimage PIC, DDS, SGI,
  PNM/PPM/PGM/PBM, Field3d.
- An ImageCache class that transparently manages a cache so that it can access
  truly vast amounts of image data.
- A really nice image viewer, iv, also based on OpenImageIO classes (and so
  will work with any formats for which plugins are available).

%package -n %{libname}
Summary:	A library for reading and writing images
Group:		System/Libraries

%description -n %{libname}
OpenImageIO is a library for reading and writing images.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}OpenImageIO-devel < 1.7.9

%description -n %{develname}
Development files for %{name} library.

%package -n python-%{name}
Summary:	Python 2 bindings for %{name}
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Provides:	python-OpenImageIO = %{version}-%{release}

%description -n python-%{name}
Python 2 bindings for %{name}.

%package -n python3-%{name}
Summary:	Python 3 bindings for %{name}
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Provides:	python3-OpenImageIO = %{version}-%{release}

%description -n python3-%{name}
Python3 bindings for %{name}.

%prep
%setup -qn oiio-Release-%{version}
%autopatch -p1

# Remove bundled pugixml
rm -f src/include/OpenImageIO/pugixml.hpp \
      src/include/OpenImageIO/pugiconfig.hpp \
      src/include/OpenImageIO/pugixml.cpp

%build
%cmake -DUSE_OPENSSL:BOOL=ON \
       -DUSE_PYTHON:BOOL=ON \
       -DUSE_PYTHON3:BOOL=ON \
       -DPYLIB_INSTALL_DIR:PATH=%{python2_sitearch} \
       -DPYLIB3_INSTALL_DIR:PATH=%{python3_sitearch} \
       -DINCLUDE_INSTALL_DIR:PATH=%{_includedir}/OpenImageIO \
       -DMAN_INSTALL_DIR:PATH=%{_mandir}/man1 \
       -DDOC_INSTALL_DIR:PATH=%{_docdir}/OpenImageIO \
       -DSTOP_ON_WARNING=OFF \
       -DUSE_EXTERNAL_PUGIXML:BOOL=ON
%make_build

%install
%make_install -C build

rm -fr %{buildroot}%{_docdir}

%files
%license LICENSE
%{_bindir}/*
%{_xfontdir}/oiio/
%{_mandir}/man1/*

%files -n %{libname}
%license LICENSE
%{_libdir}/libOpenImageIO.so.%{major}{,.*}
%{_libdir}/libOpenImageIO_Util.so.%{major}{,.*}

%files -n %{develname}
%doc CHANGES.md
%doc README.md
%doc src/doc/*.pdf
%license LICENSE
%{_libdir}/libOpenImageIO.so
%{_libdir}/libOpenImageIO_Util.so
%dir %{_includedir}/OpenImageIO
%{_includedir}/OpenImageIO/*

%files -n python-%{name}
%{python2_sitearch}/OpenImageIO.so

%files -n python3-%{name}
%{python3_sitearch}/OpenImageIO.so


%changelog
* Tue May 16 2017 luigiwalser <luigiwalser> 1.7.14-1.mga6
+ Revision: 1102070
- 1.7.14
- add patch from fedora to fix arch/optimizer specific problem with
  uninitialized variables

* Tue May 02 2017 akien <akien> 1.7.9-3.mga6
+ Revision: 1098369
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 1.7.9-2.mga6
+ Revision: 1090229
- Rebuild for ffmpeg 3.2.4

* Wed Dec 28 2016 wally <wally> 1.7.9-1.mga6
+ Revision: 1078446
- new version 1.7.9
- fix pkg names (use lower case)
- rediff linking patch

* Tue Dec 27 2016 neoclust <neoclust> 1.6.17-2.mga6
+ Revision: 1078383
- Rebuild against new libraw

* Sat Oct 01 2016 daviddavid <daviddavid> 1.6.17-1.mga6
+ Revision: 1057976
- new version: 1.6.17

* Sat Apr 09 2016 daviddavid <daviddavid> 1.6.12-1.mga6
+ Revision: 999805
- new version: 1.6.12

* Sun Jan 10 2016 daviddavid <daviddavid> 1.6.9-2.mga6
+ Revision: 920961
- rebuild for new giflib 5.1.2

* Wed Jan 06 2016 daviddavid <daviddavid> 1.6.9-1.mga6
+ Revision: 920121
- new version: 1.6.9
- now libmajor is 1.6
- update file list

* Tue Jan 05 2016 daviddavid <daviddavid> 1.5.23-1.mga6
+ Revision: 919818
- new version: 1.5.23
- reenable python binding build (upstream fixed build with boost 1.60.0)
- move python bindings to their own subpackage
- add python 3 subpackage

* Sat Jan 02 2016 luigiwalser <luigiwalser> 1.5.22-2.mga6
+ Revision: 918204
- rebuild for libwebp

* Sun Dec 27 2015 daviddavid <daviddavid> 1.5.22-1.mga6
+ Revision: 916060
- new version: 1.5.22
- rebuild for new libraw 0.17.1

* Sat Dec 26 2015 daviddavid <daviddavid> 1.5.18-3.mga6
+ Revision: 915100
- temporarily disable python binding build (uncompatible with boost 1.60.0 for now)
- rebuild for new boost 1.60.0

* Fri Sep 25 2015 daviddavid <daviddavid> 1.5.18-2.mga6
+ Revision: 883479
- rebuild for new boost 1.59.0

* Wed Aug 26 2015 fwang <fwang> 1.5.18-1.mga6
+ Revision: 869481
- install man pages
- br opencolorio
- disable doc install
- update file list
- use openssl
- add more br
- 1.5.18

* Mon Aug 24 2015 daviddavid <daviddavid> 1.2.0-15.mga6
+ Revision: 868898
- rebuild for new glew 1.13.0

* Fri Jul 31 2015 fwang <fwang> 1.2.0-14.mga6
+ Revision: 859426
- rebuild for new boost

* Tue Jun 23 2015 fwang <fwang> 1.2.0-13.mga6
+ Revision: 840506
- rebuild for new glew

* Wed Oct 15 2014 umeabot <umeabot> 1.2.0-12.mga5
+ Revision: 750496
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.0-11.mga5
+ Revision: 683214
- Mageia 5 Mass Rebuild

* Fri Sep 05 2014 luigiwalser <luigiwalser> 1.2.0-10.mga5
+ Revision: 672251
- rebuild for glew

* Sun Aug 24 2014 luigiwalser <luigiwalser> 1.2.0-9.mga5
+ Revision: 666999
- rebuild for ilmbase and OpenEXR

* Thu Aug 07 2014 fwang <fwang> 1.2.0-8.mga5
+ Revision: 660835
- rebuild for new pugixml

* Fri Apr 25 2014 akien <akien> 1.2.0-7.mga5
+ Revision: 618074
- Rebuild for new OpenEXR and IlmBase

* Sat Feb 15 2014 luigiwalser <luigiwalser> 1.2.0-6.mga5
+ Revision: 592108
- rebuild for libwebp

* Sat Feb 08 2014 barjac <barjac> 1.2.0-5.mga5
+ Revision: 586737
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 1.2.0-4.mga4
+ Revision: 534418
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 fwang <fwang> 1.2.0-3.mga4
+ Revision: 477848
- rebuild for new openexr

* Wed Jul 24 2013 sander85 <sander85> 1.2.0-2.mga4
+ Revision: 457678
- Rebuild for new glew

* Mon Jul 15 2013 fwang <fwang> 1.2.0-1.mga4
+ Revision: 454647
- disable werror
- update dl patch
- new version 1.2.0

* Mon Jul 08 2013 fwang <fwang> 1.0.8-11.mga4
+ Revision: 451208
- rebuild for new boost

* Thu Jun 06 2013 fwang <fwang> 1.0.8-10.mga4
+ Revision: 438301
- rebuild again for updated openjpeg

* Thu Jun 06 2013 fwang <fwang> 1.0.8-9.mga4
+ Revision: 438284
- rebuild for new openjpeg

* Sun Jun 02 2013 fwang <fwang> 1.0.8-8.mga4
+ Revision: 434729
- rebuild for new libpng

* Thu Apr 11 2013 barjac <barjac> 1.0.8-7.mga3
+ Revision: 409667
- rebuild for boost-1.53

* Sun Jan 13 2013 umeabot <umeabot> 1.0.8-6.mga3
+ Revision: 362041
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 1.0.8-5.mga3
+ Revision: 332957
- rebuild for new boost

* Sun Dec 02 2012 fwang <fwang> 1.0.8-4.mga3
+ Revision: 325021
- rebuild for  new openexr

* Sun Oct 07 2012 fwang <fwang> 1.0.8-3.mga3
+ Revision: 303247
- rebuild for new openjpeg

* Tue Aug 21 2012 fwang <fwang> 1.0.8-2.mga3
+ Revision: 282870
- rebuild for new glew

* Tue Jul 31 2012 fwang <fwang> 1.0.8-1.mga3
+ Revision: 276474
- new version 1.0.8
- rebuild for new glew

* Tue May 29 2012 fwang <fwang> 1.0.4-2.mga3
+ Revision: 249531
- rebuild for new boost

* Fri May 25 2012 fwang <fwang> 1.0.4-1.mga3
+ Revision: 236018
- fix upgrade from previous name
- br jpeg
- imported package openimageio

